%bcond_with tests
%bcond_with docs

%{?python_enable_dependency_generator}

%global srcname SecretStorage

Summary:        Python bindings to FreeDesktop.org Secret Service API
Name:           python-%{srcname}
Version:        3.3.3
Release:        8%{?dist}
License:        BSD
URL:            https://github.com/mitya57/secretstorage
Source0:        %pypi_source
Source1:        http://download.gnome.org/sources/libsecret/0.20/libsecret-0.20.4.tar.xz

BuildRequires:  /usr/bin/dbus-launch /usr/bin/xvfb-run python3-devel
BuildRequires:  python3-dbus python3-gobject-base python3-setuptools
BuildRequires:  python3-cryptography python3-jeepney
%if %{with docs}
BuildRequires:  python3-sphinx
%endif

BuildArch:      noarch

%description
This module provides a way for securely storing passwords and other secrets.
It uses D-Bus Secret Service API that is supported by GNOME Keyring (>= 2.30)
and KSecretsService.
The main classes provided are secretstorage.Item, representing a secret item
(that has a label, a secret and some attributes) and secretstorage.Collection,
a place items are stored in.
SecretStorage supports most of the functions provided by Secret Service,
including creating and deleting items and collections, editing items, locking
and unlocking collections (asynchronous unlocking is also supported).


%package -n python3-secretstorage
Summary:		Python bindings to FreeDesktop.org Secret Service API
Provides:		python3-%{srcname} = %{version}-%{release}

%description -n python3-secretstorage
This module provides a way for securely storing passwords and other secrets.
It uses D-Bus Secret Service API that is supported by GNOME Keyring (>= 2.30)
and KSecretsService.
The main classes provided are secretstorage.Item, representing a secret item
(that has a label, a secret and some attributes) and secretstorage.Collection,
a place items are stored in.
SecretStorage supports most of the functions provided by Secret Service,
including creating and deleting items and collections, editing items, locking
and unlocking collections (asynchronous unlocking is also supported).

%if %{with docs}
%package -n python3-secretstorage-doc
Summary:	SecretStorage documentation

%description -n python3-secretstorage-doc
Documentation for SecretStorage.
%endif

%prep
%autosetup -n %{srcname}-%{version}
tar xf %{SOURCE1}

%build
%py3_build
%if %{with docs}
%{__python3} setup.py build_sphinx
find build -name '.buildinfo' -delete -print
find build -name 'doctrees' -type d -print -delete
%endif

%install
%py3_install

%if %{with tests}
%check
export PYTHONPATH=%{buildroot}%{python3_sitelib}
for MOCK in libsecret-0.20.4/libsecret/mock-service-{normal,only-plain,lock}.py; do
  xvfb-run -a dbus-launch --exit-with-session %{__python3} tests/run_tests.py ${MOCK}
done
%endif

%files -n python3-secretstorage
%license LICENSE
%doc changelog README.rst
%{python3_sitelib}/%{srcname}-%{version}-py%{python3_version}.egg-info/
%{python3_sitelib}/secretstorage/

%if %{with docs}
%files -n python3-secretstorage-doc
%doc build/sphinx/html/*
%endif

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.3.3-8
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.3.3-7
- Rebuilt for loongarch release

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.3.3-6
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.3.3-5
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.3.3-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.3.3-3
- Rebuilt for OpenCloudOS Stream 23

* Mon Dec 26 2022 Miaojun Dong <zoedong@tencent.com> - 3.3.3-2
- Adjust buildrequires

* Thu Dec 22 2022 Miaojun Dong <zoedong@tencent.com> - 3.3.3-1
- initial build
